summaryrefslogtreecommitdiff
path: root/sysdeps/unix/sysv/linux/nios2/sys/ucontext.h
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps/unix/sysv/linux/nios2/sys/ucontext.h')
-rw-r--r--sysdeps/unix/sysv/linux/nios2/sys/ucontext.h35
1 files changed, 24 insertions, 11 deletions
diff --git a/sysdeps/unix/sysv/linux/nios2/sys/ucontext.h b/sysdeps/unix/sysv/linux/nios2/sys/ucontext.h
index a44ec61fa0..188a004ac2 100644
--- a/sysdeps/unix/sysv/linux/nios2/sys/ucontext.h
+++ b/sysdeps/unix/sysv/linux/nios2/sys/ucontext.h
@@ -1,5 +1,5 @@
-/* struct ucontext definition, Nios II version.
- Copyright (C) 2015-2016 Free Software Foundation, Inc.
+/* ucontext_t definition, Nios II version.
+ Copyright (C) 2015-2018 Free Software Foundation, Inc.
This file is part of the GNU C Library.
The GNU C Library is free software; you can redistribute it and/or
@@ -22,27 +22,40 @@
#define _SYS_UCONTEXT_H 1
#include <features.h>
-#include <signal.h>
+
+#include <bits/types/sigset_t.h>
+#include <bits/types/stack_t.h>
+
/* These definitions must be in sync with the kernel. */
-#define MCONTEXT_VERSION 2
+#ifdef __USE_MISC
+# define MCONTEXT_VERSION 2
+#endif
+
+#ifdef __USE_MISC
+# define __ctx(fld) fld
+#else
+# define __ctx(fld) __ ## fld
+#endif
/* Context to describe whole processor state. */
-typedef struct mcontext
+typedef struct
{
- int version;
- unsigned long regs[32];
+ int __ctx(version);
+ unsigned long __ctx(regs)[32];
} mcontext_t;
/* Userlevel context. */
-typedef struct ucontext
+typedef struct ucontext_t
{
- unsigned long uc_flags;
- struct ucontext *uc_link;
+ unsigned long __ctx(uc_flags);
+ struct ucontext_t *uc_link;
stack_t uc_stack;
mcontext_t uc_mcontext;
- __sigset_t uc_sigmask;
+ sigset_t uc_sigmask;
} ucontext_t;
+#undef __ctx
+
#endif /* sys/ucontext.h */